@@ -16,8 +16,8 @@
 
 import copy
 import re
+from unittest import mock
 
-import mock
 from osc_lib import exceptions
 from osc_lib.tests import utils
 
