@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # Copyright (C) 2013 Yahoo! Inc.
 # All Rights Reserved.
 #
@@ -15,8 +14,8 @@
 #    under the License.
 
 import sys
+from unittest import mock
 
-import mock
 
 from neutronclient.common import exceptions
 from neutronclient.neutron.v2_0 import quota as test_quota
